package com.ruoyi.project.training.newstaff.mapper;

import java.util.List;
import com.ruoyi.framework.aspectj.lang.annotation.DataScope;
import com.ruoyi.project.training.newstaff.domain.TTnFirstplanTmpl;

/**
 * 进组培训模版Mapper接口
 *
 * @author ruoyi
 * @date 2023-06-29
 */
public interface TTnFirstplanTmplMapper
{
    /**
     * 查询进组培训模版
     *
     * @param id 进组培训模版ID
     * @return 进组培训模版
     */
    public TTnFirstplanTmpl selectTTnFirstplanTmplById(Long id);

    /**
     * 查询进组培训模版列表
     *
     * @param tTnFirstplanTmpl 进组培训模版
     * @return 进组培训模版集合
     */
    @DataScope(deptAlias = "d")
    public List<TTnFirstplanTmpl> selectTTnFirstplanTmplList(TTnFirstplanTmpl tTnFirstplanTmpl);

    /**
     * 新增进组培训模版
     *
     * @param tTnFirstplanTmpl 进组培训模版
     * @return 结果
     */
    public int insertTTnFirstplanTmpl(TTnFirstplanTmpl tTnFirstplanTmpl);

    /**
     * 修改进组培训模版
     *
     * @param tTnFirstplanTmpl 进组培训模版
     * @return 结果
     */
    public int updateTTnFirstplanTmpl(TTnFirstplanTmpl tTnFirstplanTmpl);

    /**
     * 删除进组培训模版
     *
     * @param id 进组培训模版ID
     * @return 结果
     */
    public int deleteTTnFirstplanTmplById(Long id);

    /**
     * 批量删除进组培训模版
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTTnFirstplanTmplByIds(Long[] ids);
}
